#!/usr/bin/env python3
from sys import argv, stderr, stdin
import socket

from de.p1st.exec_notify.lib import mail


def main():
    """
    Send an email with some content and optionally specify an email subject.

    Usage:
      echo <body> | de-p1st-notify

      echo <body> | de-p1st-notify <subject>

      de-p1st-notify <body>

      de-p1st-notify <subject> <body>
    """

    BODY = None
    subj = None
    hostname = socket.gethostname()

    if len(argv) > 3:
        print('execNotify>> Expected at most two arguments!', file=stderr)
        exit(1)
    if len(argv) == 2 or len(argv) == 3:
        subj = argv[1]
    if len(argv) == 3:
        BODY = argv[2]

    if subj is None:
        subj = 'notify'
    if BODY is None:
        BODY = stdin.read()

    SUBJECT = f'{hostname} | {subj}'
    print(SUBJECT)
    print(BODY)

    mail.sendMailOrWriteToFile(SUBJECT=SUBJECT, BODY=BODY)


if __name__ == '__main__':
    main()
